pub fn register_namespace(ns: &str) -> Result<(), ()>Expand description
Register a namespace that this plugin owns for IPC commands and events.
Once registered, IPC clients can send commands to { "plugin": <ns>, "payload": ... }
(routed to Plugin::handle_command) and subscribe to this plugin’s events by <ns>.
A plugin may own at most one namespace, and each namespace may be owned by at most one
plugin. Returns Ok(()) on success, or Err(()) if this plugin already owns a
namespace or ns is already taken by another plugin.